@@ -13,6 +13,10 @@ import warnings
 
 from .globals import DEBUG
 
+# experimental
+from .eveventhandler import EventHandler
+
+
 
 EXITED_DOWN  =  1
 EXITED_UP    = -1
@@ -26,9 +30,18 @@ RAISEERROR   = 'RAISEERROR'
 
 ALLOW_NEW_INPUT = True
 
-class NotEnoughSpaceForWidget(Exception):
+TEST_SETTINGS = {
+    'TEST_INPUT': None,
+    'TEST_INPUT_LOG': [],
+    'CONTINUE_AFTER_TEST_INPUT': False,
+    }
+
+
+class ExhaustedTestInput(Exception):
     pass
 
+class NotEnoughSpaceForWidget(Exception):
+    pass
 
 class InputHandler(object):
     "An object that can handle user input"
@@ -153,7 +166,7 @@ but in most cases the add_handers or add_complex_handlers methods are what you w
 
 
 
-class Widget(InputHandler, wgwidget_proto._LinePrinter):
+class Widget(InputHandler, wgwidget_proto._LinePrinter, EventHandler):
     "A base class for widgets. Do not use directly"
     
     _SAFE_STRING_STRIPS_NL = True
@@ -242,6 +255,8 @@ class Widget(InputHandler, wgwidget_proto._LinePrinter):
             self.value_changed_callback = value_changed_callback
         else:
             self.value_changed_callback = None
+        
+        self.initialize_event_handling()
     
     def set_relyx(self, y, x):
         """
@@ -522,27 +537,40 @@ big a given widget is ... use .height and .width instead"""
                 self.parent.parentApp.while_waiting()
 
     def get_and_use_key_press(self):
-        curses.raw()
-        curses.cbreak()
-        curses.meta(1)
-        self.parent.curses_pad.keypad(1)
-        if self.parent.keypress_timeout:
-            curses.halfdelay(self.parent.keypress_timeout)
-            ch = self._get_ch()
-            if ch == -1:
-                return self.try_while_waiting()
+        global TEST_SETTINGS
+        if TEST_SETTINGS['TEST_INPUT'] is None:
+            curses.raw()
+            curses.cbreak()
+            curses.meta(1)
+            self.parent.curses_pad.keypad(1)
+            if self.parent.keypress_timeout:
+                curses.halfdelay(self.parent.keypress_timeout)
+                ch = self._get_ch()
+                if ch == -1:
+                    return self.try_while_waiting()
+            else:
+                self.parent.curses_pad.timeout(-1)
+                ch = self._get_ch()
+            # handle escape-prefixed rubbish.
+            if ch == curses.ascii.ESC:
+                #self.parent.curses_pad.timeout(1)
+                self.parent.curses_pad.nodelay(1)
+                ch2 = self.parent.curses_pad.getch()
+                if ch2 != -1: 
+                    ch = curses.ascii.alt(ch2)
+                self.parent.curses_pad.timeout(-1) # back to blocking mode
+                #curses.flushinp()
         else:
-            self.parent.curses_pad.timeout(-1)
-            ch = self._get_ch()
-        # handle escape-prefixed rubbish.
-        if ch == curses.ascii.ESC:
-            #self.parent.curses_pad.timeout(1)
-            self.parent.curses_pad.nodelay(1)
-            ch2 = self.parent.curses_pad.getch()
-            if ch2 != -1: 
-                ch = curses.ascii.alt(ch2)
-            self.parent.curses_pad.timeout(-1) # back to blocking mode
-            #curses.flushinp()
+            self._last_get_ch_was_unicode = True
+            try:
+                ch = TEST_SETTINGS['TEST_INPUT'].pop(0)
+                TEST_SETTINGS['TEST_INPUT_LOG'].append(ch)
+            except IndexError:
+                if TEST_SETTINGS['CONTINUE_AFTER_TEST_INPUT']:
+                    TEST_SETTINGS['TEST_INPUT'] = None
+                    return
+                else:
+                    raise ExhaustedTestInput
         
         self.handle_input(ch)
         if self.check_value_change:
